@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import binascii
 import re
 from asyncio import CancelledError
 from contextlib import contextmanager
@@ -17,6 +16,7 @@ from typing import Tuple
 from typing import TypeVar
 
 import gdb
+import gdb.types
 from typing_extensions import Callable
 from typing_extensions import Set
 from typing_extensions import override
